@@ -3,7 +3,7 @@
 # SPDX-FileCopyrightText: 2018-2021, Marsiske Stefan
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-import sys, os, socket, ssl, struct, platform
+import sys, os, socket, ssl, struct, platform, getpass
 from SecureString import clearmem
 import pysodium
 from qrcodegen import QrCode
@@ -303,6 +303,12 @@ def ratelimit(s,req):
   s.send(solution)
   return s
 
+def getpwd():
+  if sys.stdin.isatty():
+    return getpass.getpass("enter your password please: ").encode('utf8')
+  else:
+    return sys.stdin.buffer.readline().rstrip(b'\n')
+
 #### OPs ####
 
 def init_key():
@@ -567,8 +573,10 @@ def qrcode(output, key):
 
 def usage(params):
   print("usage: %s init" % params[0])
-  print("usage: %s <create|change> <user> <site> <[u][l][d][s] [<size>] [<symbols>]> | [<target password>]" % params[0])
-  print("usage: %s <get|commit|undo|delete> <user> <site>" % params[0])
+  print("usage: echo -n 'password' | %s <create|change> <user> <site> <[u][l][d][s] [<size>] [<symbols>]> | [<target password>]" % params[0])
+  print("usage: echo -n 'password' | %s get <user> <site>" % params[0])
+  print("usage: %s <commit|undo|delete> <user> <site> # if rwd_keys is false in your config" % params[0])
+  print("usage: echo -n 'password' | %s <commit|undo|delete> <user> <site> # if rwd_keys is true in your config" % params[0])
   print("usage: %s list <site>" % params[0])
   print("usage: %s qr [svg] [key]" % params[0])
   sys.exit(1)
@@ -577,8 +585,8 @@ def arg_rules(params):
   user = params[2]
   site = params[3]
   size = None
-  symbols = ''
-  classes = ''
+  symbols = None
+  classes = None
   target = None
   for param in params[4:]:
     if not classes and set(list(param)) - {'u','l','s','d'} == set():
@@ -603,7 +611,7 @@ def arg_rules(params):
   if target is not None and (symbols or classes or size):
     print(f"invalid args for {param[1]}: \"{params[4:]}\"", file=sys.stderr)
     usage(param)
-  return user, site, classes or '', symbols, size or 0, target
+  return user, site, classes or 'uld', symbols or bin2pass.symbols, size or 0, target
 
 def test_pwd(pwd):
   q = zxcvbn(pwd.decode('utf8'))
@@ -673,10 +681,10 @@ def main(params=sys.argv):
   if cmd is not None:
     if cmd != users:
       pwd = ''
-      if (rwd_keys or cmd in {create,change}):
-        pwd = sys.stdin.buffer.readline().rstrip(b'\n')
+      if (rwd_keys or cmd in {create,change,get}):
+        pwd = getpwd()
         if cmd == change:
-          newpwd = sys.stdin.buffer.readline().rstrip(b'\n')
+          newpwd = getpwd()
           if not newpwd:
             newpwd = pwd
           test_pwd(newpwd)
